"use strict";
/*
 * Copyright (c) 2023, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const sf_plugins_core_1 = require("@salesforce/sf-plugins-core");
const core_1 = require("@salesforce/core");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('plugin-switch-np', 'switch.connect');
class ConnectOrg extends sf_plugins_core_1.SfCommand {
    async run() {
        // parse the provided flags
        const { flags } = await this.parse(ConnectOrg);
        this.log(`Connecting to ${flags.username}...`);
        // Initialize the authorization for the provided username
        const authInfo = await core_1.AuthInfo.create({ username: flags.username });
        // Create a connection to the org
        const connection = await core_1.Connection.create({ authInfo });
        this.log(`Connected to ${flags.username} (${authInfo.getFields().orgId}) with API version ${connection.version}`);
        this.log(`${authInfo.getFields().instanceUrl}`);
    }
}
exports.default = ConnectOrg;
_a = ConnectOrg;
ConnectOrg.summary = messages.getMessage('summary');
ConnectOrg.description = messages.getMessage('description');
ConnectOrg.examples = messages.getMessages('examples');
ConnectOrg.flags = {
    username: sf_plugins_core_1.Flags.string({
        summary: _a.summary,
        char: 'u',
        required: true,
    }),
};
//# sourceMappingURL=connect.js.map