"use strict";
/*
 * Copyright (c) 2023, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const process = require("child_process");
const sf_plugins_core_1 = require("@salesforce/sf-plugins-core");
const core_1 = require("@salesforce/core");
const __1 = require("../..");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('plugin-switch-np', 'switch.switchOff');
class SwitchSwitchOff extends sf_plugins_core_1.SfCommand {
    async deactivate() {
        // deactivate trigger
        const switchCommand1 = "find . -type f -name \"*.trigger-meta.xml\" -exec sed -i '' 's/<status>Active<\\/status>/<status>Inactive<\\/status>/g' {} +";
        // deactiivate flow, process builder
        const switchCommand2 = "find . -type f -name \"*.flowDefinition-meta.xml\" -exec sed -i '' 's/<activeVersionNumber>[0-9]*<\\/activeVersionNumber>/<activeVersionNumber>0<\\/activeVersionNumber>/g' {} +";
        // deactivate validatiion rule
        const switchCommand3 = "find . -type f -name \"*.validationRule-meta.xml\" -exec sed -i '' 's/<active>true<\\/active>/<active>false<\\/active>/g' {} +";
        // deactivate workflow rule
        const switchCommand4 = "find . -type f -name \"*.workflow-meta.xml\" -exec sed -i '' 's/<active>true<\\/active>/<active>false<\\/active>/g' {} +";
        await this.sh(switchCommand1);
        await this.sh(switchCommand2);
        await this.sh(switchCommand3);
        await this.sh(switchCommand4);
        this.log('All Active statuses switched to Inactive and all true values of the <active> tag switched to false in XML files');
    }
    async run() {
        const { flags } = await this.parse(SwitchSwitchOff);
        await this.deactivate();
        const deployCommand = `sf project deploy start --manifest ${flags.package}`;
        await (0, __1.execCmd)(deployCommand, { async: true });
        return {
            path: '/Users/ngocphan/salesforce-plugins/plugin-switch/src/commands/switch/switchOff.ts',
        };
    }
    // eslint-disable-next-line class-methods-use-this
    async sh(cmd) {
        return new Promise((resolve, reject) => {
            process.exec(cmd, { maxBuffer: 2097152 }, (err, stdout, stderr) => {
                if (err) {
                    reject({ err });
                }
                else {
                    resolve({ stdout, stderr });
                }
            });
        });
    }
}
exports.default = SwitchSwitchOff;
SwitchSwitchOff.summary = messages.getMessage('summary');
SwitchSwitchOff.description = messages.getMessage('description');
SwitchSwitchOff.examples = messages.getMessages('examples');
SwitchSwitchOff.flags = {
    package: sf_plugins_core_1.Flags.string({
        summary: messages.getMessage('description'),
        char: 'x',
        required: true,
        exists: true,
    }),
};
//# sourceMappingURL=switchOff.js.map